@@ -1,7 +1,7 @@
 use crate::{arrayvec::ArrayVec, len::LengthType, mem::SpareMemoryPolicy};
 use core::iter::{FromIterator, IntoIterator};
 
-impl<T, L, SM, const C: usize> FromIterator<T> for ArrayVec<T, L, SM, C>
+impl<T, L, SM, const C: usize> FromIterator<T> for ArrayVec<T, C, L, SM>
 where
     L: LengthType,
     SM: SpareMemoryPolicy<T>,
@@ -27,14 +27,12 @@ mod testing {
     use crate as cds;
     use cds::{
         arrayvec::ArrayVec,
-        len::Usize,
-        mem::Uninitialized,
         testing::dropped::{Dropped, Track},
     };
 
     #[test]
     fn test_from_iter() {
-        type A<'a> = ArrayVec<Dropped<'a, 16>, Usize, Uninitialized, 16>;
+        type A<'a> = ArrayVec<Dropped<'a, 16>, 16>;
         let t = Track::<16>::new();
         let a = A::from_iter(t.take(5));
         assert_eq!(t.n_allocated(), 5);
@@ -47,7 +45,7 @@ mod testing {
 
     #[test]
     fn test_from_iter_copy() {
-        type A = ArrayVec<usize, Usize, Uninitialized, 8>;
+        type A = ArrayVec<usize, 8>;
         let a = A::from_iter(0..5);
         assert_eq!(a, [0, 1, 2, 3, 4]);
     }
@@ -55,7 +53,7 @@ mod testing {
     #[test]
     #[should_panic]
     fn test_from_iter_panics_on_capacity_error() {
-        type A = ArrayVec<usize, Usize, Uninitialized, 8>;
+        type A = ArrayVec<usize, 8>;
         let _a = A::from_iter(0..9);
     }
 }
